{{ fullname | escape | underline }}

.. automodule:: {{ fullname }}

{% block attributes %}
{% if attributes %}
.. rubric:: {{ _('Module Attributes') }}

.. autosummary::
{% for item in attributes %}
	{{ item }}
{%- endfor %}
{% endif %}
{% endblock %}

{% block functions %}
{% if functions %}
.. rubric:: {{ _('Functions') }}

.. autosummary::
{% for item in functions %}
	{{ item }}
{%- endfor %}
{% endif %}
{% endblock %}

{% block classes %}
{% if classes %}
.. rubric:: {{ _('Classes') }}

.. autosummary::
  :toctree:
  :template: summary-class.rst
{% for item in classes %}
	{{ item }}
{%- endfor %}
{% endif %}
{% endblock %}

{% block exceptions %}
{% if exceptions %}
.. rubric:: {{ _('Exceptions') }}

.. autosummary::
{% for item in exceptions %}
	{{ item }}
{%- endfor %}
{% endif %}
{% endblock %}

{% if functions %}
.. rubric:: {{ _("Functions") }}
{% for item in functions %}
.. autofunction:: {{ item }}
{%- endfor %}
{% endif %}

{% block modules %}
{% if modules %}
.. rubric:: Modules

.. autosummary::
	:toctree:
	:recursive:
	:template: summary-module.rst
{% for item in modules %}
{% if not '_test' in item %}
	{{ item }}
{% endif %}
{%- endfor %}
{% endif %}
{% endblock %}
